====
trim
====

Trims trailing whitespace from files.

.. image:: https://secure.travis-ci.org/myint/trim.png
   :target: https://secure.travis-ci.org/myint/trim
   :alt: Build status

-----
Usage
-----

Modify a single file::

   $ trim example.py

Recursively modify files in a directory::

   $ trim .
